slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPInterpolSetInterpolation

Sets the tolerance and maximum degree when building the interpolation polynomial.

### Synopsis

    #include "slepcnep.h"
    #include "slepcpep.h"
    PetscErrorCode NEPInterpolSetInterpolation(NEP nep,PetscReal tol,PetscInt deg)

Collective on nep

### Input Parameters

| nep | - nonlinear eigenvalue solver
| tol | - tolerance to stop computing polynomial coefficients
| deg | - maximum degree of interpolation

### Options Database Key

| -nep_interpol_interpolation_tol <tol> | - Sets the tolerance to stop computing polynomial coefficients
| -nep_interpol_interpolation_degree <degree> | - Sets the maximum degree of interpolation

### Notes

Use PETSC_DEFAULT for either argument to assign a reasonably good value.

### See Also

NEPInterpolGetInterpolation()

### Level

advanced

### Location

src/nep/impls/interpol/interpol.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages